diff --git a/app/assets/stylesheets/main.scss b/app/assets/stylesheets/main.scss
index be27d754dfa45d0a46dfd85c5468fd770ce92896..e99ab47938a25608d9f77a35cb900ae440816ae5 100644
--- a/app/assets/stylesheets/main.scss
+++ b/app/assets/stylesheets/main.scss
@@ -1,13 +1,13 @@
 @import "bootstrap";
 @import "bootstrap-responsive";
 
-/** GITLAB colors **/
+/** GitLab colors **/
 $link_color:#3A89A3;
 $blue_link: #2fa0bb;
 $style_color: #474d57;
 $hover: #fdf5d9;
 
-/** GITLAB Fonts **/
+/** GitLab Fonts **/
 @font-face { font-family: Korolev; src: url('korolev-medium-compressed.otf'); }
 
 /** MIXINS **/
@@ -106,9 +106,9 @@ $hover: #fdf5d9;
 @import "themes/ui_modern.scss";
 
 /**
- * Gitlab bootstrap.
+ * GitLab bootstrap.
  * Overrides some styles of twitter bootstrap.
- * Also give some common classes for gitlab app
+ * Also give some common classes for GitLab app
  */
 @import "gitlab_bootstrap/common.scss";
 @import "gitlab_bootstrap/typography.scss";
diff --git a/app/helpers/gitlab_markdown_helper.rb b/app/helpers/gitlab_markdown_helper.rb
index 9da695b5d2362a1cab6721373f25c494af1442b6..a7ab7c6c38c6b04a23642674991a2acd800e9f53 100644
--- a/app/helpers/gitlab_markdown_helper.rb
+++ b/app/helpers/gitlab_markdown_helper.rb
@@ -1,6 +1,6 @@
 module GitlabMarkdownHelper
   # Replaces references (i.e. @abc, #123, !456, ...) in the text with links to
-  # the appropriate items in Gitlab.
+  # the appropriate items in GitLab.
   #
   # text          - the source text
   # html_options  - extra options for the reference links as given to link_to
diff --git a/app/views/errors/gitolite.html.haml b/app/views/errors/gitolite.html.haml
index d5f51951d5e0babd4358275ec92eed49cc7e857a..699e6984db6357472d3b3edd92ee3aa7f1f66527 100644
--- a/app/views/errors/gitolite.html.haml
+++ b/app/views/errors/gitolite.html.haml
@@ -1,6 +1,6 @@
 %h1 Git Error
 %hr
-%h2 Gitlab was unable to access your Gitolite system.
+%h2 GitLab was unable to access your Gitolite system.
 
 .git_error_tips
   %h4 Tips for Administrator:
diff --git a/app/views/help/index.html.haml b/app/views/help/index.html.haml
index 025495772825e0d05eb5849e76d33f12cc738c7c..962f2175126e9616ae8cdfa180a515cbe6c3bd54 100644
--- a/app/views/help/index.html.haml
+++ b/app/views/help/index.html.haml
@@ -30,7 +30,7 @@
     %h5= link_to "API", help_api_path
 
   %li
-    %h5= link_to "Gitlab Markdown", help_markdown_path
+    %h5= link_to "GitLab Markdown", help_markdown_path
 
   %li
     %h5= link_to "SSH keys", help_ssh_path
diff --git a/app/views/help/markdown.html.haml b/app/views/help/markdown.html.haml
index 43d3d4b0f4a44c75b526aee3ec6d023b8a51a6b2..15ad4a5b06bef5b0e23d3182e05d1e725fa1af2b 100644
--- a/app/views/help/markdown.html.haml
+++ b/app/views/help/markdown.html.haml
@@ -1,4 +1,4 @@
-%h3.page_title Gitlab Flavored Markdown
+%h3.page_title GitLab Flavored Markdown
 .back_link
   = link_to help_path do 
     &larr; to index
@@ -7,7 +7,7 @@
 .row
   .span8
     %p
-      For Gitlab we developed something we call "Gitlab Flavored Markdown" (GFM).
+      For GitLab we developed something we call "GitLab Flavored Markdown" (GFM).
       It extends the standard Markdown in a few significant ways adds some useful functionality.
 
     %p You can use GFM in:
@@ -62,7 +62,7 @@
     %p becomes
     = markdown %Q{```ruby\nrequire 'redcarpet'\nmarkdown = Redcarpet.new("Hello World!")\nputs markdown.to_html\n```}
 
-    %h4 Special Gitlab references
+    %h4 Special GitLab references
 
     %p
       GFM recognizes special references.
diff --git a/app/views/help/ssh.html.haml b/app/views/help/ssh.html.haml
index 6a5812040e78cc0fab1e4c5ac04609097647efe6..3f082333a76303f10f3510c1ce25d304edd3c012 100644
--- a/app/views/help/ssh.html.haml
+++ b/app/views/help/ssh.html.haml
@@ -5,7 +5,7 @@
 %hr
 
 %p.slead
-  SSH key allows you to establish a secure connection between your computer and Gitlab
+  SSH key allows you to establish a secure connection between your computer and GitLab
 
 %p.slead
   To generate a new SSH key just open your terminal and use code below.
@@ -17,7 +17,7 @@
   \# Generating public/private rsa key pair...
 
 %p.slead
-  Next just use code below to dump your public key and add to GITLAB SSH Keys
+  Next just use code below to dump your public key and add to GitLab SSH Keys
 
 %pre.dark
   cat ~/.ssh/id_rsa.pub
diff --git a/app/views/help/system_hooks.html.haml b/app/views/help/system_hooks.html.haml
index 9fc8cbabf17e839d1d9706ac75e5ee10208d1a2e..736c818bc57cc72b0fb3d0e8655c245e51722d45 100644
--- a/app/views/help/system_hooks.html.haml
+++ b/app/views/help/system_hooks.html.haml
@@ -5,7 +5,7 @@
 %hr
 
 %p.slead
-  Your Gitlab instance can perform HTTP POST request on next event: create_project, delete_project, create_user, delete_user, change_team_member.
+  Your GitLab instance can perform HTTP POST request on next event: create_project, delete_project, create_user, delete_user, change_team_member.
   %br
   System Hooks can be used for logging or change information in LDAP server.
   %br
diff --git a/app/views/help/web_hooks.html.haml b/app/views/help/web_hooks.html.haml
index 263eadf6583ad090219600c4793d0c1a3d1a3a65..65036613fa7474c53781dfa88a6c8b55f0cad2ac 100644
--- a/app/views/help/web_hooks.html.haml
+++ b/app/views/help/web_hooks.html.haml
@@ -5,11 +5,11 @@
 %hr
 
 %p.slead
-  Every Gitlab project can trigger a web server whenever the repo is pushed to.
+  Every GitLab project can trigger a web server whenever the repo is pushed to.
   %br
   Web Hooks can be used to update an external issue tracker, trigger CI builds, update a backup mirror, or even deploy to your production server.
   %br
-  GITLAB will send POST request with commits information on every push.
+  GitLab will send POST request with commits information on every push.
 %h5 Hooks request example:
 = render "hooks/data_ex"
 
diff --git a/app/views/help/workflow.html.haml b/app/views/help/workflow.html.haml
index a3fe3b01d469242cb678a0680f0cb0e81576b43c..6062ca091bd87b7d6be2598897567b424bbb34e3 100644
--- a/app/views/help/workflow.html.haml
+++ b/app/views/help/workflow.html.haml
@@ -24,7 +24,7 @@
         git commit -am "My feature is ready"
 
   %li
-    %p Push your branch to gitlabhq
+    %p Push your branch to GitLab
     .bash
       %pre.dark
         git push origin $feature_name
diff --git a/app/views/hooks/_data_ex.html.erb b/app/views/hooks/_data_ex.html.erb
index e43714e965b93e837f0d4873d27e9c883452b96f..7dd6b9e0750ea5c02e09721d1cc071b2f8b423e5 100644
--- a/app/views/hooks/_data_ex.html.erb
+++ b/app/views/hooks/_data_ex.html.erb
@@ -32,7 +32,7 @@
             :timestamp => "2012-01-03T23:36:29+02:00",
                   :url => "http://localhost/diaspora/commits/da1560886d...",
                :author => {
-                 :name => "gitlab dev user",
+                 :name => "GitLab dev user",
                 :email => "gitlabdev@dv6700.(none)"
             }
         }
diff --git a/app/views/issues/_form.html.haml b/app/views/issues/_form.html.haml
index db7920b993dbec8ccd085a1fc090d732cafc0db6..23de7e8ed151d7f4b3aaf0f34fc7c3f9b6398e5c 100644
--- a/app/views/issues/_form.html.haml
+++ b/app/views/issues/_form.html.haml
@@ -38,7 +38,7 @@
           = f.label :description, "Details"
           .input
             = f.text_area :description, maxlength: 2000, class: "xxlarge", rows: 14
-            %p.hint Issues are parsed with #{link_to "Gitlab Flavored Markdown", help_markdown_path, target: '_blank'}.
+            %p.hint Issues are parsed with #{link_to "GitLab Flavored Markdown", help_markdown_path, target: '_blank'}.
 
 
     .actions
diff --git a/app/views/keys/index.html.haml b/app/views/keys/index.html.haml
index 8f7e2bab1b4fb678bfa4bdf5ddb12fec30d66d38..3e919c5c419f108fea55de55732b3ab20fa09215 100644
--- a/app/views/keys/index.html.haml
+++ b/app/views/keys/index.html.haml
@@ -4,7 +4,7 @@
 
 %hr
 %p.slead 
-  SSH key allows you to establish a secure connection between your computer and Gitlab
+  SSH key allows you to establish a secure connection between your computer and GitLab
 
 
 %table#keys-table
diff --git a/app/views/layouts/notify.html.haml b/app/views/layouts/notify.html.haml
index a1938df43a13c04712ec3d55ef0075e5b8fc5132..7b79897b653f85e26079db4cda305799a6ff8644 100644
--- a/app/views/layouts/notify.html.haml
+++ b/app/views/layouts/notify.html.haml
@@ -2,7 +2,7 @@
   %head
     %meta{content: "text/html; charset=utf-8", "http-equiv" => "Content-Type"}
       %title
-        gitlabhq
+        GitLab
       :css
         .header h1 {color: #BBBBBB !important; font: bold 32px Helvetica, Arial, sans-serif; margin: 0; padding: 0; line-height: 40px;}
         .header p {color: #c6c6c6; font: normal 12px Helvetica, Arial, sans-serif; margin: 0; padding: 0; line-height: 18px;}
@@ -21,7 +21,7 @@
                 \ 
               %td{align: "left", style: "padding: 18px 0 10px;", width: "580"}
                 %h1{style: "color: #BBBBBB; font: normal 32px Helvetica, Arial, sans-serif; margin: 0; padding: 0; line-height: 40px;"}
-                  gitlab
+                  GITLAB
                   - if @project
                     | #{@project.name}
           %table{align: "center", bgcolor: "#fff", border: "0", cellpadding: "0", cellspacing: "0", style: "font-family: Helvetica, Arial, sans-serif; background: #fff;", width: "600"}
diff --git a/app/views/milestones/_form.html.haml b/app/views/milestones/_form.html.haml
index 41cbd6abcadcf067d26ad0aa1b29731945a4605e..ce4145ba3e6f3c12b4c20a4da9602f6a50661f0e 100644
--- a/app/views/milestones/_form.html.haml
+++ b/app/views/milestones/_form.html.haml
@@ -22,7 +22,7 @@
         = f.label :description, "Description", class: "control-label"
         .controls
           = f.text_area :description, maxlength: 2000, class: "input-xlarge", rows: 10
-          %p.hint Milestones are parsed with #{link_to "Gitlab Flavored Markdown", help_markdown_path, target: '_blank'}.
+          %p.hint Milestones are parsed with #{link_to "GitLab Flavored Markdown", help_markdown_path, target: '_blank'}.
     .span6
       .control-group
         = f.label :due_date, "Due Date", class: "control-label"
diff --git a/app/views/notes/_form.html.haml b/app/views/notes/_form.html.haml
index 7211a0ae471ce02665cd237f67394525177e5091..6d559cfc790c08cf68b06e1a27dfd463f02d7c8f 100644
--- a/app/views/notes/_form.html.haml
+++ b/app/views/notes/_form.html.haml
@@ -11,7 +11,7 @@
     = f.text_area :note, size: 255, class: 'note-text'
     #preview-note.preview_note.hide
     .hint
-      .right Comments are parsed with #{link_to "Gitlab Flavored Markdown", help_markdown_path, target: '_blank'}.
+      .right Comments are parsed with #{link_to "GitLab Flavored Markdown", help_markdown_path, target: '_blank'}.
       .clearfix
 
     .row.note_advanced_opts.hide
diff --git a/app/views/notify/new_user_email.html.haml b/app/views/notify/new_user_email.html.haml
index d96afc92fe27482e88e1c8363d7154198ac1a831..93bf7c50229bd6e393cb55d369a7bbe6377cda75 100644
--- a/app/views/notify/new_user_email.html.haml
+++ b/app/views/notify/new_user_email.html.haml
@@ -6,7 +6,7 @@
         %h2{style: "color:#646464; font-weight: bold; margin: 0; padding: 0; line-height: 26px; font-size: 18px; font-family: Helvetica, Arial, sans-serif; "}
           Hi #{@user['name']}!
         %p{style: "color:#767676; font-weight: normal; margin: 0; padding: 0; line-height: 20px; font-size: 12px;font-family: Helvetica, Arial, sans-serif; "}
-          Administrator created account for you. Now you are a member of company gitlab application.
+          Administrator created account for you. Now you are a member of company GitLab application.
       %td{style: "font-size: 1px; line-height: 1px;", width: "21"}
     %tr
       %td{style: "font-size: 1px; line-height: 1px;", width: "21"}
diff --git a/app/views/wikis/_form.html.haml b/app/views/wikis/_form.html.haml
index 12b57e032a4d3ee0f6d532f6ee7d6d016bf25b54..b05d0a7899210cfdfe76b74ed2dea440026325a2 100644
--- a/app/views/wikis/_form.html.haml
+++ b/app/views/wikis/_form.html.haml
@@ -14,7 +14,7 @@
     .middle_box_content
       .input
         %span.cgray
-          Wiki content is parsed with #{link_to "Gitlab Flavored Markdown", help_markdown_path, target: '_blank'}.
+          Wiki content is parsed with #{link_to "GitLab Flavored Markdown", help_markdown_path, target: '_blank'}.
           To link to a (new) page you can just type
           %code [Link Title](page-slug)
           \.
diff --git a/doc/api/README.md b/doc/api/README.md
index dece3e23619adac8ca2a7aa82e0ccc2e3eb66f88..93919b42852546edf529eeaadc77504385d93127 100644
--- a/doc/api/README.md
+++ b/doc/api/README.md
@@ -1,4 +1,4 @@
-# Gitlab API
+# GitLab API
 
 All API requests require authentication. You need to pass a `private_token` parameter to authenticate. You can find or reset your private token in your profile.
 
@@ -10,7 +10,7 @@ If no, or an invalid, `private_token` is provided then an error message will be
 }
 ```
 
-API requests should be prefixed with `api` and the API version. The API version is equal to the Gitlab major version number, which is defined in `lib/api.rb`.
+API requests should be prefixed with `api` and the API version. The API version is equal to the GitLab major version number, which is defined in `lib/api.rb`.
 
 Example of a valid API request:
 
diff --git a/doc/installation.md b/doc/installation.md
index 327fc192822fb9e55a8c4e6b7c5c4641cc5cfe94..e14ec711e7b6899e65e7510f6469c5be4584a195 100644
--- a/doc/installation.md
+++ b/doc/installation.md
@@ -167,7 +167,7 @@ and ensure you have followed all of the above steps carefully.
     # Login to MySQL
     $ mysql -u root -p
 
-    # Create the gitlabhq production database
+    # Create the GitLab production database
     mysql> CREATE DATABASE IF NOT EXISTS `gitlabhq_production` DEFAULT CHARACTER SET `utf8` COLLATE `utf8_unicode_ci`;
 
     # Create the MySQL User change $password to a real password
diff --git a/lib/gitlab/backend/gitolite.rb b/lib/gitlab/backend/gitolite.rb
index b69f4663c35b2e05e4c6f74ec18b0d6409f1676e..3dfb574c4d5dc53a1a63db3dc69a2edaab523f85 100644
--- a/lib/gitlab/backend/gitolite.rb
+++ b/lib/gitlab/backend/gitolite.rb
@@ -170,7 +170,7 @@ module Gitlab
     def push
       Dir.chdir(File.join(@local_dir, "gitolite"))
       `git add -A`
-      `git commit -am "Gitlab"`
+      `git commit -am "GitLab"`
       `git push`
       Dir.chdir(Rails.root)
 
diff --git a/lib/gitlab/markdown.rb b/lib/gitlab/markdown.rb
index 9a07133d0b377e19865fee6001c72c2e1950bf4a..a387b503ccb9b007d44ae19951039bd2b539300a 100644
--- a/lib/gitlab/markdown.rb
+++ b/lib/gitlab/markdown.rb
@@ -1,5 +1,5 @@
 module Gitlab
-  # Custom parser for Gitlab-flavored Markdown
+  # Custom parser for GitLab-flavored Markdown
   #
   # It replaces references in the text with links to the appropriate items in Gitlab.
   #
diff --git a/lib/hooks/post-receive b/lib/hooks/post-receive
index d38bd13e19d8fa0b85c4b88ea3b10959b2823451..a4fa9f1c2346670412ecf2f32dfc8786c88a5252 100755
--- a/lib/hooks/post-receive
+++ b/lib/hooks/post-receive
@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
-# This file was placed here by Gitlab. It makes sure that your pushed commits
+# This file was placed here by GitLab. It makes sure that your pushed commits
 # will be processed properly.
 
 while read oldrev newrev ref
diff --git a/lib/tasks/gitlab/write_hook.rake b/lib/tasks/gitlab/write_hook.rake
index 9ec9c8383e21bd7429155e5050eacb2e0a390953..5e9fc8eb3d1f7b427cf3eb20ba268acf917cedf7 100644
--- a/lib/tasks/gitlab/write_hook.rake
+++ b/lib/tasks/gitlab/write_hook.rake
@@ -1,6 +1,6 @@
 namespace :gitlab do
   namespace :gitolite do
-    desc "GITLAB | Write GITLAB hook for gitolite"
+    desc "GITLAB | Write GitLab hook for gitolite"
     task :write_hooks => :environment  do
       gitolite_hooks_path = File.join(Gitlab.config.git_hooks_path, "common")
       gitlab_hooks_path = Rails.root.join("lib", "hooks")
diff --git a/app/mailers/notify.rb b/app/mailers/notify.rb
index 91136fee95ee7006fb34534833fb9480c9e2e924..0afc1d31ef472999d793e7c2ccb2b02b93401e14 100644
--- a/app/mailers/notify.rb
+++ b/app/mailers/notify.rb
@@ -111,18 +111,18 @@ class Notify < ActionMailer::Base
   # Examples
   #
   #   >> subject('Lorem ipsum')
-  #   => "gitlab | Lorem ipsum"
+  #   => "GitLab | Lorem ipsum"
   #
   #   # Automatically inserts Project name when @project is set
   #   >> @project = Project.last
   #   => #<Project id: 1, name: "Ruby on Rails", path: "ruby_on_rails", ...>
   #   >> subject('Lorem ipsum')
   #   => "gitlab | Lorem ipsum | Ruby on Rails"
   #
   #   # Accepts multiple arguments
   #   >> subject('Lorem ipsum', 'Dolor sit amet')
   #   => "gitlab | Lorem ipsum | Dolor sit amet"
   def subject(*extra)
-    "gitlab | " << extra.join(' | ') << (@project ? " | #{@project.name}" : "")
+    "GitLab | " << extra.join(' | ') << (@project ? " | #{@project.name}" : "")
   end
 end
@@ -111,18 +111,18 @@ class Notify < ActionMailer::Base
   #   => #<Project id: 1, name: "Ruby on Rails", path: "ruby_on_rails", ...>
   #   >> subject('Lorem ipsum')
-  #   => "gitlab | Lorem ipsum | Ruby on Rails"
+  #   => "GitLab | Lorem ipsum | Ruby on Rails"
   #
   #   # Accepts multiple arguments
@@ -111,18 +111,18 @@ class Notify < ActionMailer::Base
   #   # Accepts multiple arguments
   #   >> subject('Lorem ipsum', 'Dolor sit amet')
-  #   => "gitlab | Lorem ipsum | Dolor sit amet"
+  #   => "GitLab | Lorem ipsum | Dolor sit amet"
   def subject(*extra)